Request

#[non_exhaustive]
pub enum Request<'a> { SetSelection { source: Option<ExtDataControlSourceV1>, }, Destroy, SetPrimarySelection { source: Option<ExtDataControlSourceV1>, }, }

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


SetSelection

copy data to the selection

This request asks the compositor to set the selection to the data from the source on behalf of the client.

The given source may not be used in any further set_selection or set_primary_selection requests. Attempting to use a previously used source triggers the used_source protocol error.

To unset the selection, set the source to NULL.



Destroy

destroy this data device

Destroys the data device object.

This is a destructor, once sent this object cannot be used any longer.



SetPrimarySelection

copy data to the primary selection

This request asks the compositor to set the primary selection to the data from the source on behalf of the client.

The given source may not be used in any further set_selection or set_primary_selection requests. Attempting to use a previously used source triggers the used_source protocol error.

To unset the primary selection, set the source to NULL.

The compositor will ignore this request if it does not support primary selection.

Implementations

Source

impl<'a> Request<'a>

pub fn opcode(&self) -> u16

Get the opcode number of this message